package com.cs.bd.commerce.util.http;

import android.annotation.SuppressLint;
import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.provider.Settings;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.view.WindowManager;

import com.cs.bd.commerce.util.AppUtils;
import com.cs.bd.commerce.util.GoogleMarketUtils;
import com.cs.statistic.StatisticsManager;

import java.util.Locale;


/**
 * 用于获取http协议头phead常用的参数
 *
 * @author matt
 * @date: 2015年11月17日
 *
 */
public class HttpHeadUtil {

	private static String sAndroidId;
	/**
	 * <br>功能简述:获取Android ID的方法
	 * <br>功能详细描述:
	 * <br>注意:
	 * @return
	 */
	public static String getAndroidId(Context context) {
		if (sAndroidId == null && context != null) {
			sAndroidId = Settings.Secure.getString(context.getContentResolver(),
					Settings.Secure.ANDROID_ID);
		}
		return sAndroidId;
	}
	
	private static int sVersionCode = -1;
	public static int getVersionCode(Context context) {
		if (sVersionCode == -1) {
			sVersionCode = AppUtils.getAppVersionCode(context);
		}
		return sVersionCode;
	}
	
	private static String sVersionName = null;
	/**
	 * 获取桌面版本号
	 * 
	 * @author xiedezhi
	 * 
	 * @param context
	 * @return
	 */
	public static String getVersionName(Context context) {
		if (sVersionName == null) {
			sVersionName = AppUtils.getAppVersionName(context);
		}
		return sVersionName;
	}
	
	/**
	 * 从res/raw/uid.txt文件中获取渠道id
	 * 
	 * @author huyong
	 * @param context
	 * @return
	 */
	public static String getUid(Context context) {
		return "200"; // uid默认为200
	}
	
	/**
	 * 获取国家，返回结果为大写字母
	 * 
	 * @param context
	 * @return 
	 * @备注 先获取sim卡的国家，如果没有sim卡，取本地语言代表的国家
	 */
	public static String getCountry(Context context) {
		String ret = null;
		try {
			TelephonyManager telManager = (TelephonyManager) context
					.getSystemService(Context.TELEPHONY_SERVICE);
			if (telManager != null) {
				ret = telManager.getSimCountryIso().toUpperCase();
			}
		} catch (Throwable e) {
		}
		if (TextUtils.isEmpty(ret)) {
			ret = Locale.getDefault().getCountry().toUpperCase();
		}

		return TextUtils.isEmpty(ret) ? "ZZ" : ret;
	}

	/**
	 * 获取国家，返回结果为大写字母
	 * 
	 * @param context
	 * @return 
	 * @备注 先获取sim卡的国家，如果没有sim卡，取本地语言代表的国家
	 */
	public static String getLocal(Context context) {
		return getCountry(context);
	}
	
	/**
	 * 获取语言，返回小写字母
	 * 
	 * @return
	 */
	public static String getLanguage(Context context) {
		return Locale.getDefault().getLanguage().toLowerCase();
	}
	
	/**
	 * 获取用户运营商代码
	 * @param context
	 * @return
	 */
	public static String getCnUser(Context context) {
		return "";
	}
	
	/**
	 * 获取设备宽高320*480
	 * 
	 * @param context
	 * @return
	 */
	public static String getDeviceDIPString(Context context) {
		WindowManager wMgr = (WindowManager) context
				.getSystemService(Context.WINDOW_SERVICE);
		return wMgr.getDefaultDisplay().getWidth() + "*"
				+ wMgr.getDefaultDisplay().getHeight();
	}
	
	/**
	 * 获取设备DIP
	 * @param context
	 * @return
	 */
	public static int getDeviceDIP(Context context) {
		DisplayMetrics dm = new DisplayMetrics();
		WindowManager wMgr = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
		wMgr.getDefaultDisplay().getMetrics(dm);
		return dm != null ? dm.densityDpi : 0;
	}
	
	/**
	 * 是否存在google电子市场
	 * @param context
	 * @return
	 */
	public static boolean isExistGoogleMarket(Context context) {
		return GoogleMarketUtils.isMarketExist(context);
	}
	
	/**
	 * 获取当前网络类型，wifi，GPRS，3G，4G
	 * 
	 * @param context
	 * @return
	 */
	public static String getNetType(Context context) {
		// build Network conditions
		String ret = "";
		try {
			ConnectivityManager manager = (ConnectivityManager) context
					.getSystemService(Context.CONNECTIVITY_SERVICE);
			@SuppressLint("MissingPermission") NetworkInfo networkinfo = manager.getActiveNetworkInfo();
			if (networkinfo != null && networkinfo.getType() == ConnectivityManager.TYPE_WIFI) {
				ret = "WIFI";
			} else if (networkinfo != null && networkinfo.getType() == ConnectivityManager.TYPE_MOBILE) {
				int subtype = networkinfo.getSubtype();
				switch (subtype) {
					case TelephonyManager.NETWORK_TYPE_1xRTT :
					case TelephonyManager.NETWORK_TYPE_CDMA :
					case TelephonyManager.NETWORK_TYPE_EDGE :
					case TelephonyManager.NETWORK_TYPE_GPRS :
					case TelephonyManager.NETWORK_TYPE_IDEN :
						// 2G
						ret = "2G" /*+ "(typeid = " + networkinfo.getType() + "  typename = "
									+ networkinfo.getTypeName() + "  subtypeid = "
									+ networkinfo.getSubtype() + "  subtypename = "
									+ networkinfo.getSubtypeName() + ")"*/;
						break;
					case TelephonyManager.NETWORK_TYPE_EVDO_0 :
					case TelephonyManager.NETWORK_TYPE_EVDO_A :
					case TelephonyManager.NETWORK_TYPE_HSDPA :
					case TelephonyManager.NETWORK_TYPE_HSPA :
					case TelephonyManager.NETWORK_TYPE_HSUPA :
					case TelephonyManager.NETWORK_TYPE_UMTS :
						// 3G,4G
						ret = "3G/4G" /*+ "(typeid = " + networkinfo.getType() + "  typename = "
										+ networkinfo.getTypeName() + "  subtypeid = "
										+ networkinfo.getSubtype() + "  subtypename = "
										+ networkinfo.getSubtypeName() + ")"*/;
						break;
					case TelephonyManager.NETWORK_TYPE_UNKNOWN :
					default :
						// unknow
						ret = "UNKNOW" /*+ "(typeid = " + networkinfo.getType() + "  typename = "
										+ networkinfo.getTypeName() + "  subtypeid = "
										+ networkinfo.getSubtype() + "  subtypename = "
										+ networkinfo.getSubtypeName() + ")"*/;
						break;
				}
			} else {
				ret = "UNKNOW" /*+ "(typeid = " + networkinfo.getType() + "  typename = "
								+ networkinfo.getTypeName() + ")"*/;
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return ret;
	}
	
	public static String getGoId(Context context) {
		return StatisticsManager.getUserId(context);
	}
}
